@@ -18,6 +18,7 @@ from more_itertools import first_true
 from .engine import Engine
 from .page import Page
 
+
 class RSSFeedEngine(Engine):
     """The Engine that Processes RSS Feed"""
 
@@ -74,7 +75,7 @@ class RSSFeedItem:
         self.guid = getattr(cls, "guid", cls.slug)
         logging.debug(vars(cls))
         self.link = cls.url
-        self.pub_date = cls.date_published
+        self.pub_date = cls.date_published.to_rfc2822_string()
 
 
 class RSSFeed(Page):
@@ -82,11 +83,11 @@ class RSSFeed(Page):
 
     template = "rss2.0.rss"
     engine = RSSFeedEngine()
-    title = "RSS Feed"
     link = ""
     slug = ""
 
-    def __init__(self, collection):
+    def __init__(self, title, collection):
         super().__init__()
         self.no_index = True
+        self.title = title
         self.items = [item.rss_feed_item for item in collection.pages]
